marktools.attach_articulations_to_notes_and_chords_in_expr
==========================================================

.. autofunction:: abjad.tools.marktools.attach_articulations_to_notes_and_chords_in_expr.attach_articulations_to_notes_and_chords_in_expr
